@@ -79,13 +79,36 @@ sub masonParameters
       $iface->{'virtual'} = $net->vifacesConf($_);
     } elsif ($net->ifaceMethod($_) eq 'trunk') {
       push(@params, 'vlans' => $net->ifaceVlans($_));
+    } elsif ($net->ifaceMethod($_) eq 'ppp') {
+      $iface->{'ppp_user'} = $net->ifacePPPUser($_);
+      $iface->{'ppp_pass'} = $net->ifacePPPPass($_);
     }
   }
-
+  my $externalWarning = 0;
+  if ($net->ifaceIsExternal($ifname)) {
+	$externalWarning = _externalWarning($ifname);
+  }
+  push(@params, 'externalWarning' => $externalWarning);
   push(@params, 'iface' => $iface);
   push(@params, 'ifaces' => \@ifaces);
 
   return \@params;
 }
 
+sub _externalWarning
+{
+  my ($iface) =  @_;
+  my $req = Apache2::RequestUtil->request();
+
+  return 0 unless ($req);
+  my $remote = $req->connection->remote_ip();
+  my $command = "/sbin/ip route get to $remote " 
+		. ' | head -n 1 | sed -e "s/.*dev \(\w\+\).*/\1/" ';
+  my $routeIface = `$command`;
+  return 0 unless ( $? == 0);
+  chop($routeIface);
+  if (defined($routeIface) and $routeIface eq $iface) {
+	return 1;
+  }
+}
 1;
