@@ -12,16 +12,14 @@ EBox::init();
 my $global = EBox::Global->getInstance(1);
 my $network = $global->modInstance("network");
 
-my $iface = shift;
-my $address = shift;
-my $mask = shift;
+my ($iface, $address, $mask) = @ARGV;
 
 $iface or exit;
 $address or exit;
 $mask or exit;
 
 try {
-	$network->setDHCPAddress($iface, $address, $mask);
+    $network->setDHCPAddress($iface, $address, $mask);
 } finally {
-	exit;
+    exit;
 };
